gluple/transform

Functions

pub fn replace_last1(: #(a), data: b) -> #(b)
pub fn replace_last2(tuple: #(a, b), data: c) -> #(a, c)
pub fn replace_last3(tuple: #(a, b, c), data: d) -> #(a, b, d)
pub fn replace_last4(
  tuple: #(a, b, c, d),
  data: e,
) -> #(a, b, c, e)
pub fn replace_last5(
  tuple: #(a, b, c, d, e),
  data: f,
) -> #(a, b, c, d, f)
pub fn replace_last6(
  tuple: #(a, b, c, d, e, f),
  data: g,
) -> #(a, b, c, d, e, g)
pub fn replace_last7(
  tuple: #(a, b, c, d, e, f, g),
  data: h,
) -> #(a, b, c, d, e, f, h)
pub fn replace_last8(
  tuple: #(a, b, c, d, e, f, g, h),
  data: i,
) -> #(a, b, c, d, e, f, g, i)
pub fn replace_last9(
  tuple: #(a, b, c, d, e, f, g, h, i),
  data: j,
) -> #(a, b, c, d, e, f, g, h, j)
Search Document